@@ -1,10 +1,12 @@
 # Import tests from other packages
+from lfs.cart.tests import *
 from lfs.catalog.tests import *
 from lfs.marketing.tests import *
 from lfs.order.tests import *
 from lfs.page.tests import *
 from lfs.search.tests import *
 from lfs.shipping.tests import *
+from lfs.voucher.tests import *
 
 # django imports
 from django.contrib.auth.models import User
